@@ -5,16 +5,20 @@ Commands are:
     model create_sql drop_sql
 """
 
+import sys
+import os
+import pylons
+
+import migrate.versioning.api as migrate_api
+
 from paste.script.command import Command, BadCommand
 from paste.script.filemaker import FileOp
 from paste.util import import_string
 from paste import deploy
-from migrate.versioning.exceptions import KnownError, DatabaseAlreadyControlledError
 
-import sys
-import os
-import pylons.util as util
-import migrate.versioning.api as migrate_api
+from migrate.versioning.exceptions import KnownError, \
+    DatabaseAlreadyControlledError
+
 
 class SqlCommand(Command):
         
@@ -37,11 +41,12 @@ class SqlCommand(Command):
 
             file_op = FileOp(source_dir=os.path.join(os.path.dirname(__file__)))
             base_package = file_op.find_dir('models', True)[0]
-            package = __import__(base_package + '.models')
-            model = package.models
+            package = __import__(base_package + '.model')
+            model = package.model
 
             app = deploy.loadapp('config:' + config_file)
-            metadata = model.metadata
+            context = model.get_context()
+            metadata = context.metadata
 
             try:
                 table_name = self.args[1]
@@ -57,6 +62,7 @@ class SqlCommand(Command):
             msg = str(sys.exc_info()[1])
             raise BadCommand('An unknown error occurred. %s' % msg)
 
+
 class CreateSqlCommand(SqlCommand):
     """Create all model tables, or a single table
 
@@ -114,7 +120,7 @@ class ModelCommand(Command):
     Example usage::
     
         yourproj% paster model user
-        Creating yourproj/yourproj/models/user.py
+        Creating yourproj/yourproj/model/user.py
         Creating yourproj/yourproj/tests/unit/test_user.py
     
     If you'd like to have models underneath a directory, just include
@@ -122,8 +128,8 @@ class ModelCommand(Command):
     created for you::
     
         yourproj% paster model user/permissions
-        Creating yourproj/models/user
-        Creating yourproj/yourproj/models/user/permissions.py
+        Creating yourproj/model/user
+        Creating yourproj/yourproj/model/user/permissions.py
         Creating yourproj/yourproj/tests/functional/test_user_permissions.py
     """
     summary = __doc__.splitlines()[0]
@@ -151,7 +157,7 @@ class ModelCommand(Command):
                 raise BadCommand('No egg_info directory was found')
             
             # Check the name isn't the same as the package
-            base_package = file_op.find_dir('models', True)[0]
+            base_package = file_op.find_dir('model', True)[0]
             if base_package.lower() == name.lower():
                 raise BadCommand(
                     'Your model name should not be the same as '
@@ -163,7 +169,7 @@ class ModelCommand(Command):
                         
             # Setup the model
             fullname = os.path.join(directory, name)
-            model_name = util.class_name_from_module_name(
+            model_name = pylons.util.class_name_from_module_name(
                 name.split('/')[-1])
             if not fullname.startswith(os.sep):
                 fullname = os.sep + fullname
@@ -174,7 +180,7 @@ class ModelCommand(Command):
                                           'package':base_package,
                                           'test_model_name':test_model_name})
             file_op.copy_file(template='model.py_tmpl',
-                         dest=os.path.join('models', directory), 
+                         dest=os.path.join('model', directory), 
                          filename=name)
             if not self.options.no_test:
                 file_op.copy_file(template='test_model.py_tmpl',
@@ -186,6 +192,7 @@ class ModelCommand(Command):
             msg = str(sys.exc_info()[1])
             raise BadCommand('An unknown error occurred. %s' % msg)
 
+
 class RunnerCommand(Command):
     """Create and run background scripts
     
@@ -338,7 +345,7 @@ class MigrateCommand(Command):
 
         # add database to version control
         version = self.options.version
-        dburi = self.options.dburi or util.config_get('sqlalchemy.dburi')
+        dburi = self.options.dburi or pylons.config.get('sqlalchemy.default.uri')
         try:
             migrate_api.version_control(dburi, repository)
         except DatabaseAlreadyControlledError:
