@@ -1,12 +1,13 @@
 from authprojectname.lib.base import *
 from authprojectname.lib.auth import signin, signout
 
-"""
-A stub login controller, with signin and signout methods
-"""
 class LoginController(BaseController):
+
+    "A stub login controller, with signin and signout methods"
+
     def index(self):
         return Response('login_form')
+
     def signin(self):
         username = request.params.get('username')
         password = request.params.get('password')
@@ -15,9 +16,10 @@ class LoginController(BaseController):
             signin(user)
             redirect_to('/')
         else:
-            redirect_to(action = 'index')
+            redirect_to(action='index')
+
     def signout(self):
         signout()
-        redirect_to(action = 'login')
+        redirect_to(action='login')
  
         
\ No newline at end of file
