@@ -1,14 +1,14 @@
 from authprojectname.lib.base import *
 
 class TemplateController(BaseController):
+
     def view(self, url):
-        """
-        By default the final controller tried to fulfill the request when no
-        other routes match. It may be used to display a template when all else
-        fails, e.g.::
+        """By default, the final controller tried to fulfill the request when
+        no other routes match. It may be used to display a template when all
+        else fails, e.g.::
 
             def view(self, url):
-                return render_response('/%s' % url)
+                return render('/%s' % url)
 
         Or if you're using Mako and want to explicitly send a 404 (Not Found)
         response code when the requested template doesn't exist::
@@ -17,7 +17,7 @@ class TemplateController(BaseController):
 
             def view(self, url):
                 try:
-                    return render_response('/%s' % url)
+                    return render('/%s' % url)
                 except mako.exceptions.TopLevelLookupException:
                     abort(404)
 
