@@ -7,7 +7,7 @@ from pylons.i18n import N_, _, ungettext
 from authkit.pylons_adaptors import authorize
 from authprojectname.lib.auth import get_user, RemoteUser, InGroup, HasPermission
 from authprojectname.lib.helpers import get_object_or_404
-import authprojectname.models as model
+import authprojectname.model as model
 import authprojectname.lib.helpers as h
 
 
@@ -15,6 +15,8 @@ class BaseController(WSGIController):
     def __call__(self, environ, start_response):
         # Refresh database session
         model.resync()
+        # Add current user to template
+        c.current_user = get_user()
         # Insert any code to be run per request here. The Routes match
         # is under environ['pylons.routes_dict'] should you want to check
         # the action or route vars here
