@@ -5,5 +5,5 @@ def setup_config(command, filename, section, vars):
     Place any commands to setup authprojectname here.
     """    
     app = loadapp('config:' + filename)
-    from authprojectname import models as model
+    from authprojectname import model as model
     model.connect()
