@@ -5,7 +5,7 @@ from pylons.templating import render, render_response
 from pylons.helpers import abort, redirect_to, etag_cache
 from pylons.i18n import N_, _, ungettext
 from projectname.lib.helpers import get_object_or_404
-import projectname.models as model
+import projectname.model as model
 import projectname.lib.helpers as h
 
 class BaseController(WSGIController):
