@@ -1,8 +1,6 @@
 import sacontext
 import elixir
 
-context = None
-
 class ElixirStrategy(sacontext.ContextualStrategy):
 
     def create_session(self, context):
@@ -15,13 +13,13 @@ class ElixirStrategy(sacontext.ContextualStrategy):
     def get_connectable(self, key, context):
         return context.get_engine(key)
 
-def connect():
+context = sacontext.PylonsSAContext(strategy=ElixirStrategy())
+
+def connect(name=None):
     """
     Connects engine 
     """
-    global context
-    context = sacontext.PylonsSAContext(strategy=ElixirStrategy())
-    context.add_engine_from_config(None)
+    context.add_engine_from_config(name)
     elixir.setup_all()
 
 def resync():
