@@ -26,7 +26,7 @@ cmd = paste.script.appinstall.SetupCommand('setup-app')
 cmd.run([test_file])
 
 wsgiapp = loadapp('config:test.ini', relative_to=conf_dir)
-from projectname import models as model
+from projectname import model as model
 model.connect()
 
 class TestModel(TestCase):
