@@ -5,7 +5,7 @@ def setup_config(command, filename, section, vars):
     Place any commands to setup sandbox here.
     """    
     app = loadapp('config:' + filename)
-    from projectname import models as model
+    from projectname import model as model
     model.connect()
     newsitem = model.NewsItem(title = 'Sample', content='OK')
     newsitem.flush()
